
=========
Functions
=========

Arithmetic
----------

.. toctree::
    :maxdepth: 1

    functions/arithmetic
    functions/periodic
    functions/sample
    functions/cross_sectional
    functions/group
    functions/miscellaneous
    functions/ols
